# Autogenerated code, do not edit
# some links for references:
# https://serverfault.com/questions/1068253/what-kind-of-server-has-416-cores
# https://instances.vantage.sh/
# https://azure-instances.info/
# https://gcpinstances.doit-intl.com/

from nbox.nbxlib.resource_constants import PresetMachineConfig

# Computer types in Amazon Web Services
class AWS:
  """
  Almost all the machines available in AWS are listed here.

  For more information please refer the [AWS EC2 page](https://aws.amazon.com/ec2/instance-types/).
  """
  c6a_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c6a.12xlarge', 'backend': 'AWS'})
  c6a_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c6a.24xlarge', 'backend': 'AWS'})
  c6a_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c6a.2xlarge', 'backend': 'AWS'})
  c6a_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c6a.4xlarge', 'backend': 'AWS'})
  c6a_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c6a.8xlarge', 'backend': 'AWS'})
  c6a_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c6a.large', 'backend': 'AWS'})
  c6a_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c6a.xlarge', 'backend': 'AWS'})
  c6gn_medium = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'c6gn.medium', 'backend': 'AWS'})
  c6i_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c6i.12xlarge', 'backend': 'AWS'})
  c6i_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c6i.24xlarge', 'backend': 'AWS'})
  c6i_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c6i.2xlarge', 'backend': 'AWS'})
  c6i_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c6i.4xlarge', 'backend': 'AWS'})
  c6i_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c6i.8xlarge', 'backend': 'AWS'})
  c6i_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c6i.large', 'backend': 'AWS'})
  c6i_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c6i.xlarge', 'backend': 'AWS'})
  c6id_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c6id.12xlarge', 'backend': 'AWS'})
  c6id_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c6id.24xlarge', 'backend': 'AWS'})
  c6id_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c6id.2xlarge', 'backend': 'AWS'})
  c6id_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c6id.4xlarge', 'backend': 'AWS'})
  c6id_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c6id.8xlarge', 'backend': 'AWS'})
  c6id_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c6id.large', 'backend': 'AWS'})
  c6id_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c6id.xlarge', 'backend': 'AWS'})
  c7g_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c7g.12xlarge', 'backend': 'AWS'})
  c7g_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c7g.16xlarge', 'backend': 'AWS'})
  c7g_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c7g.2xlarge', 'backend': 'AWS'})
  c7g_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c7g.4xlarge', 'backend': 'AWS'})
  c7g_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c7g.8xlarge', 'backend': 'AWS'})
  c7g_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c7g.large', 'backend': 'AWS'})
  c7g_medium = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'c7g.medium', 'backend': 'AWS'})
  c7g_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c7g.xlarge', 'backend': 'AWS'})
  d3_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'd3.2xlarge', 'backend': 'AWS'})
  d3_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'd3.4xlarge', 'backend': 'AWS'})
  d3_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'd3.xlarge', 'backend': 'AWS'})
  dl1_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'dl1.24xlarge', 'backend': 'AWS'})
  g4ad_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',gpu='2',gpu_name='amd-radeon-pro-v520',metadata={'api_name': 'g4ad.8xlarge', 'backend': 'AWS'})
  g5_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',gpu='4',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.12xlarge', 'backend': 'AWS'})
  i4i_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'i4i.16xlarge', 'backend': 'AWS'})
  i4i_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'i4i.2xlarge', 'backend': 'AWS'})
  i4i_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'i4i.8xlarge', 'backend': 'AWS'})
  m6a_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm6a.12xlarge', 'backend': 'AWS'})
  m6a_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm6a.24xlarge', 'backend': 'AWS'})
  m6a_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm6a.2xlarge', 'backend': 'AWS'})
  m6a_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm6a.4xlarge', 'backend': 'AWS'})
  m6a_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm6a.8xlarge', 'backend': 'AWS'})
  m6a_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm6a.large', 'backend': 'AWS'})
  m6a_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm6a.xlarge', 'backend': 'AWS'})
  m6i_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm6i.12xlarge', 'backend': 'AWS'})
  m6i_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm6i.24xlarge', 'backend': 'AWS'})
  m6i_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm6i.2xlarge', 'backend': 'AWS'})
  m6i_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm6i.4xlarge', 'backend': 'AWS'})
  m6i_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm6i.8xlarge', 'backend': 'AWS'})
  m6i_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm6i.large', 'backend': 'AWS'})
  m6i_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm6i.xlarge', 'backend': 'AWS'})
  m6id_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm6id.12xlarge', 'backend': 'AWS'})
  m6id_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm6id.24xlarge', 'backend': 'AWS'})
  m6id_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm6id.2xlarge', 'backend': 'AWS'})
  m6id_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm6id.4xlarge', 'backend': 'AWS'})
  m6id_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm6id.8xlarge', 'backend': 'AWS'})
  m6id_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm6id.large', 'backend': 'AWS'})
  m6id_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm6id.xlarge', 'backend': 'AWS'})
  p4d_24xlarge = PresetMachineConfig(cpu='96000m',memory='1152Gi',gpu='8',gpu_name='nvidia-a100',metadata={'api_name': 'p4d.24xlarge', 'backend': 'AWS'})
  p4de_24xlarge = PresetMachineConfig(cpu='96000m',memory='1152Gi',gpu='8',gpu_name='nvidia-a100',metadata={'api_name': 'p4de.24xlarge', 'backend': 'AWS'})
  r6a_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r6a.12xlarge', 'backend': 'AWS'})
  r6a_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r6a.24xlarge', 'backend': 'AWS'})
  r6a_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r6a.2xlarge', 'backend': 'AWS'})
  r6a_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r6a.4xlarge', 'backend': 'AWS'})
  r6a_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r6a.8xlarge', 'backend': 'AWS'})
  r6a_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r6a.large', 'backend': 'AWS'})
  r6a_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r6a.xlarge', 'backend': 'AWS'})
  r6i_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r6i.12xlarge', 'backend': 'AWS'})
  r6i_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r6i.24xlarge', 'backend': 'AWS'})
  r6i_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r6i.2xlarge', 'backend': 'AWS'})
  r6i_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r6i.4xlarge', 'backend': 'AWS'})
  r6i_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r6i.8xlarge', 'backend': 'AWS'})
  r6i_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r6i.large', 'backend': 'AWS'})
  r6i_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r6i.xlarge', 'backend': 'AWS'})
  r6id_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r6id.12xlarge', 'backend': 'AWS'})
  r6id_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r6id.24xlarge', 'backend': 'AWS'})
  r6id_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r6id.2xlarge', 'backend': 'AWS'})
  r6id_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r6id.4xlarge', 'backend': 'AWS'})
  r6id_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r6id.8xlarge', 'backend': 'AWS'})
  r6id_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r6id.large', 'backend': 'AWS'})
  r6id_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r6id.xlarge', 'backend': 'AWS'})
  vt1_3xlarge = PresetMachineConfig(cpu='12000m',memory='24Gi',metadata={'api_name': 'vt1.3xlarge', 'backend': 'AWS'})
  vt1_6xlarge = PresetMachineConfig(cpu='24000m',memory='48Gi',metadata={'api_name': 'vt1.6xlarge', 'backend': 'AWS'})
  d3en_6xlarge = PresetMachineConfig(cpu='24000m',memory='96Gi',metadata={'api_name': 'd3en.6xlarge', 'backend': 'AWS'})
  c5n_18xlarge = PresetMachineConfig(cpu='72000m',memory='192Gi',metadata={'api_name': 'c5n.18xlarge', 'backend': 'AWS'})
  c5n_metal = PresetMachineConfig(cpu='72000m',memory='192Gi',metadata={'api_name': 'c5n.metal', 'backend': 'AWS'})
  c6gn_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6gn.16xlarge', 'backend': 'AWS'})
  g4dn_metal = PresetMachineConfig(cpu='96000m',memory='384Gi',gpu='8',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.metal', 'backend': 'AWS'})
  g5_48xlarge = PresetMachineConfig(cpu='192000m',memory='768Gi',gpu='8',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.48xlarge', 'backend': 'AWS'})
  i3en_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'i3en.24xlarge', 'backend': 'AWS'})
  i3en_metal = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'i3en.metal', 'backend': 'AWS'})
  im4gn_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'im4gn.16xlarge', 'backend': 'AWS'})
  inf1_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'inf1.24xlarge', 'backend': 'AWS'})
  m5dn_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5dn.24xlarge', 'backend': 'AWS'})
  m5dn_metal = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5dn.metal', 'backend': 'AWS'})
  m5n_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5n.24xlarge', 'backend': 'AWS'})
  m5n_metal = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5n.metal', 'backend': 'AWS'})
  m5zn_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5zn.12xlarge', 'backend': 'AWS'})
  m5zn_metal = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5zn.metal', 'backend': 'AWS'})
  p3dn_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',gpu='8',gpu_name='nvidia-tesla-v100',metadata={'api_name': 'p3dn.24xlarge', 'backend': 'AWS'})
  r5dn_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5dn.24xlarge', 'backend': 'AWS'})
  r5dn_metal = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5dn.metal', 'backend': 'AWS'})
  r5n_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5n.24xlarge', 'backend': 'AWS'})
  r5n_metal = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5n.metal', 'backend': 'AWS'})
  u_12tb1_112xlarge = PresetMachineConfig(cpu='448000m',memory='12288Gi',metadata={'api_name': 'u-12tb1.112xlarge', 'backend': 'AWS'})
  u_12tb1_metal = PresetMachineConfig(cpu='448000m',memory='12288Gi',metadata={'api_name': 'u-12tb1.metal', 'backend': 'AWS'})
  u_18tb1_metal = PresetMachineConfig(cpu='448000m',memory='18432Gi',metadata={'api_name': 'u-18tb1.metal', 'backend': 'AWS'})
  u_24tb1_metal = PresetMachineConfig(cpu='448000m',memory='24576Gi',metadata={'api_name': 'u-24tb1.metal', 'backend': 'AWS'})
  u_6tb1_112xlarge = PresetMachineConfig(cpu='448000m',memory='6144Gi',metadata={'api_name': 'u-6tb1.112xlarge', 'backend': 'AWS'})
  u_6tb1_56xlarge = PresetMachineConfig(cpu='224000m',memory='6144Gi',metadata={'api_name': 'u-6tb1.56xlarge', 'backend': 'AWS'})
  u_6tb1_metal = PresetMachineConfig(cpu='448000m',memory='6144Gi',metadata={'api_name': 'u-6tb1.metal', 'backend': 'AWS'})
  u_9tb1_112xlarge = PresetMachineConfig(cpu='448000m',memory='9216Gi',metadata={'api_name': 'u-9tb1.112xlarge', 'backend': 'AWS'})
  u_9tb1_metal = PresetMachineConfig(cpu='448000m',memory='9216Gi',metadata={'api_name': 'u-9tb1.metal', 'backend': 'AWS'})
  x2idn_32xlarge = PresetMachineConfig(cpu='128000m',memory='2048Gi',metadata={'api_name': 'x2idn.32xlarge', 'backend': 'AWS'})
  x2idn_metal = PresetMachineConfig(cpu='128000m',memory='2048Gi',metadata={'api_name': 'x2idn.metal', 'backend': 'AWS'})
  x2iedn_32xlarge = PresetMachineConfig(cpu='128000m',memory='4096Gi',metadata={'api_name': 'x2iedn.32xlarge', 'backend': 'AWS'})
  x2iedn_metal = PresetMachineConfig(cpu='128000m',memory='4096Gi',metadata={'api_name': 'x2iedn.metal', 'backend': 'AWS'})
  x2iezn_12xlarge = PresetMachineConfig(cpu='48000m',memory='1536Gi',metadata={'api_name': 'x2iezn.12xlarge', 'backend': 'AWS'})
  x2iezn_metal = PresetMachineConfig(cpu='48000m',memory='1536Gi',metadata={'api_name': 'x2iezn.metal', 'backend': 'AWS'})
  c6gn_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c6gn.12xlarge', 'backend': 'AWS'})
  d3en_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'd3en.12xlarge', 'backend': 'AWS'})
  i4i_32xlarge = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'i4i.32xlarge', 'backend': 'AWS'})
  i4i_metal = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'i4i.metal', 'backend': 'AWS'})
  m5dn_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm5dn.16xlarge', 'backend': 'AWS'})
  m5n_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm5n.16xlarge', 'backend': 'AWS'})
  r5dn_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5dn.16xlarge', 'backend': 'AWS'})
  r5n_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5n.16xlarge', 'backend': 'AWS'})
  x2idn_24xlarge = PresetMachineConfig(cpu='96000m',memory='1536Gi',metadata={'api_name': 'x2idn.24xlarge', 'backend': 'AWS'})
  x2iedn_24xlarge = PresetMachineConfig(cpu='96000m',memory='3072Gi',metadata={'api_name': 'x2iedn.24xlarge', 'backend': 'AWS'})
  x2iezn_8xlarge = PresetMachineConfig(cpu='32000m',memory='1024Gi',metadata={'api_name': 'x2iezn.8xlarge', 'backend': 'AWS'})
  c5n_9xlarge = PresetMachineConfig(cpu='36000m',memory='96Gi',metadata={'api_name': 'c5n.9xlarge', 'backend': 'AWS'})
  c6a_32xlarge = PresetMachineConfig(cpu='128000m',memory='256Gi',metadata={'api_name': 'c6a.32xlarge', 'backend': 'AWS'})
  c6a_48xlarge = PresetMachineConfig(cpu='192000m',memory='384Gi',metadata={'api_name': 'c6a.48xlarge', 'backend': 'AWS'})
  c6a_metal = PresetMachineConfig(cpu='192000m',memory='384Gi',metadata={'api_name': 'c6a.metal', 'backend': 'AWS'})
  c6gn_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c6gn.8xlarge', 'backend': 'AWS'})
  c6i_32xlarge = PresetMachineConfig(cpu='128000m',memory='256Gi',metadata={'api_name': 'c6i.32xlarge', 'backend': 'AWS'})
  c6i_metal = PresetMachineConfig(cpu='128000m',memory='256Gi',metadata={'api_name': 'c6i.metal', 'backend': 'AWS'})
  c6id_32xlarge = PresetMachineConfig(cpu='128000m',memory='256Gi',metadata={'api_name': 'c6id.32xlarge', 'backend': 'AWS'})
  c6id_metal = PresetMachineConfig(cpu='128000m',memory='256Gi',metadata={'api_name': 'c6id.metal', 'backend': 'AWS'})
  d3en_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'd3en.8xlarge', 'backend': 'AWS'})
  g4dn_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',gpu='4',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.12xlarge', 'backend': 'AWS'})
  g4dn_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',gpu='1',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.16xlarge', 'backend': 'AWS'})
  g4dn_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',gpu='1',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.8xlarge', 'backend': 'AWS'})
  g5_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',gpu='4',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.24xlarge', 'backend': 'AWS'})
  i3en_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'i3en.12xlarge', 'backend': 'AWS'})
  im4gn_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'im4gn.8xlarge', 'backend': 'AWS'})
  is4gen_8xlarge = PresetMachineConfig(cpu='32000m',memory='192Gi',metadata={'api_name': 'is4gen.8xlarge', 'backend': 'AWS'})
  m5dn_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5dn.12xlarge', 'backend': 'AWS'})
  m5n_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5n.12xlarge', 'backend': 'AWS'})
  m5zn_6xlarge = PresetMachineConfig(cpu='24000m',memory='96Gi',metadata={'api_name': 'm5zn.6xlarge', 'backend': 'AWS'})
  m6a_32xlarge = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'm6a.32xlarge', 'backend': 'AWS'})
  m6a_48xlarge = PresetMachineConfig(cpu='192000m',memory='768Gi',metadata={'api_name': 'm6a.48xlarge', 'backend': 'AWS'})
  m6a_metal = PresetMachineConfig(cpu='192000m',memory='768Gi',metadata={'api_name': 'm6a.metal', 'backend': 'AWS'})
  m6i_32xlarge = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'm6i.32xlarge', 'backend': 'AWS'})
  m6i_metal = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'm6i.metal', 'backend': 'AWS'})
  m6id_32xlarge = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'm6id.32xlarge', 'backend': 'AWS'})
  m6id_metal = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'm6id.metal', 'backend': 'AWS'})
  r5dn_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5dn.12xlarge', 'backend': 'AWS'})
  r5n_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5n.12xlarge', 'backend': 'AWS'})
  r6a_32xlarge = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'r6a.32xlarge', 'backend': 'AWS'})
  r6a_48xlarge = PresetMachineConfig(cpu='192000m',memory='1536Gi',metadata={'api_name': 'r6a.48xlarge', 'backend': 'AWS'})
  r6a_metal = PresetMachineConfig(cpu='192000m',memory='1536Gi',metadata={'api_name': 'r6a.metal', 'backend': 'AWS'})
  r6i_32xlarge = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'r6i.32xlarge', 'backend': 'AWS'})
  r6i_metal = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'r6i.metal', 'backend': 'AWS'})
  r6id_32xlarge = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'r6id.32xlarge', 'backend': 'AWS'})
  r6id_metal = PresetMachineConfig(cpu='128000m',memory='1024Gi',metadata={'api_name': 'r6id.metal', 'backend': 'AWS'})
  u_3tb1_56xlarge = PresetMachineConfig(cpu='224000m',memory='3072Gi',metadata={'api_name': 'u-3tb1.56xlarge', 'backend': 'AWS'})
  x2idn_16xlarge = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'x2idn.16xlarge', 'backend': 'AWS'})
  x2iedn_16xlarge = PresetMachineConfig(cpu='64000m',memory='2048Gi',metadata={'api_name': 'x2iedn.16xlarge', 'backend': 'AWS'})
  x2iezn_6xlarge = PresetMachineConfig(cpu='24000m',memory='768Gi',metadata={'api_name': 'x2iezn.6xlarge', 'backend': 'AWS'})
  c5_18xlarge = PresetMachineConfig(cpu='72000m',memory='144Gi',metadata={'api_name': 'c5.18xlarge', 'backend': 'AWS'})
  c5_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c5.24xlarge', 'backend': 'AWS'})
  c5_metal = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c5.metal', 'backend': 'AWS'})
  c5d_18xlarge = PresetMachineConfig(cpu='72000m',memory='144Gi',metadata={'api_name': 'c5d.18xlarge', 'backend': 'AWS'})
  c5d_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c5d.24xlarge', 'backend': 'AWS'})
  c5d_metal = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c5d.metal', 'backend': 'AWS'})
  c6a_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6a.16xlarge', 'backend': 'AWS'})
  c6g_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6g.16xlarge', 'backend': 'AWS'})
  c6g_metal = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6g.metal', 'backend': 'AWS'})
  c6gd_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6gd.16xlarge', 'backend': 'AWS'})
  c6gd_metal = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6gd.metal', 'backend': 'AWS'})
  c6i_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6i.16xlarge', 'backend': 'AWS'})
  c6id_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c6id.16xlarge', 'backend': 'AWS'})
  d3_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'd3.8xlarge', 'backend': 'AWS'})
  d3en_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'd3en.4xlarge', 'backend': 'AWS'})
  f1_16xlarge = PresetMachineConfig(cpu='64000m',memory='976Gi',metadata={'api_name': 'f1.16xlarge', 'backend': 'AWS'})
  g3_16xlarge = PresetMachineConfig(cpu='64000m',memory='488Gi',gpu='4',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'g3.16xlarge', 'backend': 'AWS'})
  g4ad_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',gpu='4',gpu_name='amd-radeon-pro-v520',metadata={'api_name': 'g4ad.16xlarge', 'backend': 'AWS'})
  g5_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',gpu='1',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.16xlarge', 'backend': 'AWS'})
  g5_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',gpu='1',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.8xlarge', 'backend': 'AWS'})
  g5g_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',gpu='2',gpu_name='nvidia-t4g-tensor-core',metadata={'api_name': 'g5g.16xlarge', 'backend': 'AWS'})
  g5g_metal = PresetMachineConfig(cpu='64000m',memory='128Gi',gpu='2',gpu_name='nvidia-t4g-tensor-core',metadata={'api_name': 'g5g.metal', 'backend': 'AWS'})
  h1_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'h1.16xlarge', 'backend': 'AWS'})
  i3_16xlarge = PresetMachineConfig(cpu='64000m',memory='488Gi',metadata={'api_name': 'i3.16xlarge', 'backend': 'AWS'})
  i3_metal = PresetMachineConfig(cpu='72000m',memory='512Gi',metadata={'api_name': 'i3.metal', 'backend': 'AWS'})
  i3en_6xlarge = PresetMachineConfig(cpu='24000m',memory='192Gi',metadata={'api_name': 'i3en.6xlarge', 'backend': 'AWS'})
  im4gn_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'im4gn.4xlarge', 'backend': 'AWS'})
  inf1_6xlarge = PresetMachineConfig(cpu='24000m',memory='48Gi',metadata={'api_name': 'inf1.6xlarge', 'backend': 'AWS'})
  is4gen_4xlarge = PresetMachineConfig(cpu='16000m',memory='96Gi',metadata={'api_name': 'is4gen.4xlarge', 'backend': 'AWS'})
  m4_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm4.16xlarge', 'backend': 'AWS'})
  m5_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5.24xlarge', 'backend': 'AWS'})
  m5_metal = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5.metal', 'backend': 'AWS'})
  m5d_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5d.24xlarge', 'backend': 'AWS'})
  m5d_metal = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5d.metal', 'backend': 'AWS'})
  m5dn_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm5dn.8xlarge', 'backend': 'AWS'})
  m5n_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm5n.8xlarge', 'backend': 'AWS'})
  m6a_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6a.16xlarge', 'backend': 'AWS'})
  m6g_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6g.16xlarge', 'backend': 'AWS'})
  m6g_metal = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6g.metal', 'backend': 'AWS'})
  m6gd_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6gd.16xlarge', 'backend': 'AWS'})
  m6gd_metal = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6gd.metal', 'backend': 'AWS'})
  m6i_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6i.16xlarge', 'backend': 'AWS'})
  m6id_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm6id.16xlarge', 'backend': 'AWS'})
  mac1_metal = PresetMachineConfig(cpu='12000m',memory='32Gi',metadata={'api_name': 'mac1.metal', 'backend': 'AWS'})
  p2_16xlarge = PresetMachineConfig(cpu='64000m',memory='732Gi',gpu='16',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'p2.16xlarge', 'backend': 'AWS'})
  p3_16xlarge = PresetMachineConfig(cpu='64000m',memory='488Gi',gpu='8',gpu_name='nvidia-tesla-v100',metadata={'api_name': 'p3.16xlarge', 'backend': 'AWS'})
  r4_16xlarge = PresetMachineConfig(cpu='64000m',memory='488Gi',metadata={'api_name': 'r4.16xlarge', 'backend': 'AWS'})
  r5_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5.24xlarge', 'backend': 'AWS'})
  r5_metal = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5.metal', 'backend': 'AWS'})
  r5b_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5b.24xlarge', 'backend': 'AWS'})
  r5b_metal = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5b.metal', 'backend': 'AWS'})
  r5d_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5d.24xlarge', 'backend': 'AWS'})
  r5d_metal = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5d.metal', 'backend': 'AWS'})
  r5dn_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5dn.8xlarge', 'backend': 'AWS'})
  r5n_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5n.8xlarge', 'backend': 'AWS'})
  r6a_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6a.16xlarge', 'backend': 'AWS'})
  r6g_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6g.16xlarge', 'backend': 'AWS'})
  r6g_metal = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6g.metal', 'backend': 'AWS'})
  r6gd_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6gd.16xlarge', 'backend': 'AWS'})
  r6gd_metal = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6gd.metal', 'backend': 'AWS'})
  r6i_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6i.16xlarge', 'backend': 'AWS'})
  r6id_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r6id.16xlarge', 'backend': 'AWS'})
  vt1_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'vt1.24xlarge', 'backend': 'AWS'})
  x1_32xlarge = PresetMachineConfig(cpu='128000m',memory='1952Gi',metadata={'api_name': 'x1.32xlarge', 'backend': 'AWS'})
  x1e_32xlarge = PresetMachineConfig(cpu='128000m',memory='3904Gi',metadata={'api_name': 'x1e.32xlarge', 'backend': 'AWS'})
  x2gd_16xlarge = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'x2gd.16xlarge', 'backend': 'AWS'})
  x2gd_metal = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'x2gd.metal', 'backend': 'AWS'})
  x2iedn_8xlarge = PresetMachineConfig(cpu='32000m',memory='1024Gi',metadata={'api_name': 'x2iedn.8xlarge', 'backend': 'AWS'})
  z1d_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'z1d.12xlarge', 'backend': 'AWS'})
  z1d_metal = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'z1d.metal', 'backend': 'AWS'})
  c5n_2xlarge = PresetMachineConfig(cpu='8000m',memory='21Gi',metadata={'api_name': 'c5n.2xlarge', 'backend': 'AWS'})
  c5n_4xlarge = PresetMachineConfig(cpu='16000m',memory='42Gi',metadata={'api_name': 'c5n.4xlarge', 'backend': 'AWS'})
  c6gn_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c6gn.2xlarge', 'backend': 'AWS'})
  c6gn_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c6gn.4xlarge', 'backend': 'AWS'})
  c6gn_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c6gn.large', 'backend': 'AWS'})
  c6gn_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c6gn.xlarge', 'backend': 'AWS'})
  d3en_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'd3en.2xlarge', 'backend': 'AWS'})
  d3en_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'd3en.xlarge', 'backend': 'AWS'})
  g4dn_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',gpu='1',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.2xlarge', 'backend': 'AWS'})
  g4dn_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',gpu='1',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.4xlarge', 'backend': 'AWS'})
  g4dn_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',gpu='1',gpu_name='nvidia-t4-tensor-core',metadata={'api_name': 'g4dn.xlarge', 'backend': 'AWS'})
  g5_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',gpu='1',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.4xlarge', 'backend': 'AWS'})
  i3en_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'i3en.2xlarge', 'backend': 'AWS'})
  i3en_3xlarge = PresetMachineConfig(cpu='12000m',memory='96Gi',metadata={'api_name': 'i3en.3xlarge', 'backend': 'AWS'})
  i3en_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'i3en.large', 'backend': 'AWS'})
  i3en_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'i3en.xlarge', 'backend': 'AWS'})
  i4i_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'i4i.4xlarge', 'backend': 'AWS'})
  im4gn_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'im4gn.2xlarge', 'backend': 'AWS'})
  im4gn_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'im4gn.large', 'backend': 'AWS'})
  im4gn_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'im4gn.xlarge', 'backend': 'AWS'})
  inf1_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'inf1.2xlarge', 'backend': 'AWS'})
  inf1_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'inf1.xlarge', 'backend': 'AWS'})
  is4gen_2xlarge = PresetMachineConfig(cpu='8000m',memory='48Gi',metadata={'api_name': 'is4gen.2xlarge', 'backend': 'AWS'})
  is4gen_large = PresetMachineConfig(cpu='2000m',memory='12Gi',metadata={'api_name': 'is4gen.large', 'backend': 'AWS'})
  is4gen_medium = PresetMachineConfig(cpu='1000m',memory='6Gi',metadata={'api_name': 'is4gen.medium', 'backend': 'AWS'})
  is4gen_xlarge = PresetMachineConfig(cpu='4000m',memory='24Gi',metadata={'api_name': 'is4gen.xlarge', 'backend': 'AWS'})
  m5dn_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5dn.2xlarge', 'backend': 'AWS'})
  m5dn_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm5dn.4xlarge', 'backend': 'AWS'})
  m5dn_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5dn.large', 'backend': 'AWS'})
  m5dn_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5dn.xlarge', 'backend': 'AWS'})
  m5n_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5n.2xlarge', 'backend': 'AWS'})
  m5n_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm5n.4xlarge', 'backend': 'AWS'})
  m5n_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5n.large', 'backend': 'AWS'})
  m5n_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5n.xlarge', 'backend': 'AWS'})
  m5zn_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5zn.2xlarge', 'backend': 'AWS'})
  m5zn_3xlarge = PresetMachineConfig(cpu='12000m',memory='48Gi',metadata={'api_name': 'm5zn.3xlarge', 'backend': 'AWS'})
  m5zn_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5zn.large', 'backend': 'AWS'})
  m5zn_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5zn.xlarge', 'backend': 'AWS'})
  r5dn_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5dn.2xlarge', 'backend': 'AWS'})
  r5dn_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5dn.4xlarge', 'backend': 'AWS'})
  r5dn_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5dn.large', 'backend': 'AWS'})
  r5dn_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5dn.xlarge', 'backend': 'AWS'})
  r5n_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5n.2xlarge', 'backend': 'AWS'})
  r5n_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5n.4xlarge', 'backend': 'AWS'})
  r5n_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5n.large', 'backend': 'AWS'})
  r5n_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5n.xlarge', 'backend': 'AWS'})
  x2iedn_2xlarge = PresetMachineConfig(cpu='8000m',memory='256Gi',metadata={'api_name': 'x2iedn.2xlarge', 'backend': 'AWS'})
  x2iedn_4xlarge = PresetMachineConfig(cpu='16000m',memory='512Gi',metadata={'api_name': 'x2iedn.4xlarge', 'backend': 'AWS'})
  x2iedn_xlarge = PresetMachineConfig(cpu='4000m',memory='128Gi',metadata={'api_name': 'x2iedn.xlarge', 'backend': 'AWS'})
  x2iezn_2xlarge = PresetMachineConfig(cpu='8000m',memory='256Gi',metadata={'api_name': 'x2iezn.2xlarge', 'backend': 'AWS'})
  x2iezn_4xlarge = PresetMachineConfig(cpu='16000m',memory='512Gi',metadata={'api_name': 'x2iezn.4xlarge', 'backend': 'AWS'})
  c5a_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c5a.16xlarge', 'backend': 'AWS'})
  c5a_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c5a.24xlarge', 'backend': 'AWS'})
  c5ad_16xlarge = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'c5ad.16xlarge', 'backend': 'AWS'})
  c5ad_24xlarge = PresetMachineConfig(cpu='96000m',memory='192Gi',metadata={'api_name': 'c5ad.24xlarge', 'backend': 'AWS'})
  c6g_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c6g.12xlarge', 'backend': 'AWS'})
  c6gd_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c6gd.12xlarge', 'backend': 'AWS'})
  m5_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm5.16xlarge', 'backend': 'AWS'})
  m5a_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5a.24xlarge', 'backend': 'AWS'})
  m5ad_24xlarge = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'm5ad.24xlarge', 'backend': 'AWS'})
  m5d_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm5d.16xlarge', 'backend': 'AWS'})
  m6g_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm6g.12xlarge', 'backend': 'AWS'})
  m6gd_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm6gd.12xlarge', 'backend': 'AWS'})
  r5_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5.16xlarge', 'backend': 'AWS'})
  r5a_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5a.24xlarge', 'backend': 'AWS'})
  r5ad_24xlarge = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'r5ad.24xlarge', 'backend': 'AWS'})
  r5b_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5b.16xlarge', 'backend': 'AWS'})
  r5d_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5d.16xlarge', 'backend': 'AWS'})
  r6g_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r6g.12xlarge', 'backend': 'AWS'})
  r6gd_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r6gd.12xlarge', 'backend': 'AWS'})
  x2gd_12xlarge = PresetMachineConfig(cpu='48000m',memory='768Gi',metadata={'api_name': 'x2gd.12xlarge', 'backend': 'AWS'})
  c5_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c5.12xlarge', 'backend': 'AWS'})
  c5a_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c5a.12xlarge', 'backend': 'AWS'})
  c5ad_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c5ad.12xlarge', 'backend': 'AWS'})
  c5d_12xlarge = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'c5d.12xlarge', 'backend': 'AWS'})
  c6g_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c6g.8xlarge', 'backend': 'AWS'})
  c6gd_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c6gd.8xlarge', 'backend': 'AWS'})
  g5g_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',gpu='1',gpu_name='nvidia-t4g-tensor-core',metadata={'api_name': 'g5g.8xlarge', 'backend': 'AWS'})
  m5a_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm5a.16xlarge', 'backend': 'AWS'})
  m5ad_16xlarge = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'm5ad.16xlarge', 'backend': 'AWS'})
  m6g_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm6g.8xlarge', 'backend': 'AWS'})
  m6gd_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm6gd.8xlarge', 'backend': 'AWS'})
  r5a_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5a.16xlarge', 'backend': 'AWS'})
  r5ad_16xlarge = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'r5ad.16xlarge', 'backend': 'AWS'})
  r6g_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r6g.8xlarge', 'backend': 'AWS'})
  r6gd_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r6gd.8xlarge', 'backend': 'AWS'})
  x2gd_8xlarge = PresetMachineConfig(cpu='32000m',memory='512Gi',metadata={'api_name': 'x2gd.8xlarge', 'backend': 'AWS'})
  c4_8xlarge = PresetMachineConfig(cpu='36000m',memory='60Gi',metadata={'api_name': 'c4.8xlarge', 'backend': 'AWS'})
  c5_9xlarge = PresetMachineConfig(cpu='36000m',memory='72Gi',metadata={'api_name': 'c5.9xlarge', 'backend': 'AWS'})
  c5a_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c5a.8xlarge', 'backend': 'AWS'})
  c5ad_8xlarge = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c5ad.8xlarge', 'backend': 'AWS'})
  c5d_9xlarge = PresetMachineConfig(cpu='36000m',memory='72Gi',metadata={'api_name': 'c5d.9xlarge', 'backend': 'AWS'})
  d2_8xlarge = PresetMachineConfig(cpu='36000m',memory='244Gi',metadata={'api_name': 'd2.8xlarge', 'backend': 'AWS'})
  g3_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',gpu='2',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'g3.8xlarge', 'backend': 'AWS'})
  h1_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'h1.8xlarge', 'backend': 'AWS'})
  i3_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',metadata={'api_name': 'i3.8xlarge', 'backend': 'AWS'})
  m4_10xlarge = PresetMachineConfig(cpu='40000m',memory='160Gi',metadata={'api_name': 'm4.10xlarge', 'backend': 'AWS'})
  m5_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5.12xlarge', 'backend': 'AWS'})
  m5_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm5.8xlarge', 'backend': 'AWS'})
  m5a_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5a.12xlarge', 'backend': 'AWS'})
  m5ad_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5ad.12xlarge', 'backend': 'AWS'})
  m5d_12xlarge = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'm5d.12xlarge', 'backend': 'AWS'})
  m5d_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm5d.8xlarge', 'backend': 'AWS'})
  p2_8xlarge = PresetMachineConfig(cpu='32000m',memory='488Gi',gpu='8',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'p2.8xlarge', 'backend': 'AWS'})
  p3_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',gpu='4',gpu_name='nvidia-tesla-v100',metadata={'api_name': 'p3.8xlarge', 'backend': 'AWS'})
  r4_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',metadata={'api_name': 'r4.8xlarge', 'backend': 'AWS'})
  r5_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5.12xlarge', 'backend': 'AWS'})
  r5_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5.8xlarge', 'backend': 'AWS'})
  r5a_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5a.12xlarge', 'backend': 'AWS'})
  r5ad_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5ad.12xlarge', 'backend': 'AWS'})
  r5b_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5b.12xlarge', 'backend': 'AWS'})
  r5b_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5b.8xlarge', 'backend': 'AWS'})
  r5d_12xlarge = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'r5d.12xlarge', 'backend': 'AWS'})
  r5d_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5d.8xlarge', 'backend': 'AWS'})
  x1_16xlarge = PresetMachineConfig(cpu='64000m',memory='976Gi',metadata={'api_name': 'x1.16xlarge', 'backend': 'AWS'})
  x1e_16xlarge = PresetMachineConfig(cpu='64000m',memory='1952Gi',metadata={'api_name': 'x1e.16xlarge', 'backend': 'AWS'})
  z1d_6xlarge = PresetMachineConfig(cpu='24000m',memory='192Gi',metadata={'api_name': 'z1d.6xlarge', 'backend': 'AWS'})
  c3_8xlarge = PresetMachineConfig(cpu='32000m',memory='60Gi',metadata={'api_name': 'c3.8xlarge', 'backend': 'AWS'})
  cr1_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',metadata={'api_name': 'cr1.8xlarge', 'backend': 'AWS'})
  hs1_8xlarge = PresetMachineConfig(cpu='16000m',memory='117Gi',metadata={'api_name': 'hs1.8xlarge', 'backend': 'AWS'})
  i2_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',metadata={'api_name': 'i2.8xlarge', 'backend': 'AWS'})
  mac2_metal = PresetMachineConfig(cpu='12000m',memory='16Gi',metadata={'api_name': 'mac2.metal', 'backend': 'AWS'})
  r3_8xlarge = PresetMachineConfig(cpu='32000m',memory='244Gi',metadata={'api_name': 'r3.8xlarge', 'backend': 'AWS'})
  a1_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'a1.2xlarge', 'backend': 'AWS'})
  a1_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'a1.4xlarge', 'backend': 'AWS'})
  a1_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'a1.large', 'backend': 'AWS'})
  a1_medium = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'a1.medium', 'backend': 'AWS'})
  a1_metal = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'a1.metal', 'backend': 'AWS'})
  a1_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'a1.xlarge', 'backend': 'AWS'})
  c5_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c5.2xlarge', 'backend': 'AWS'})
  c5_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c5.4xlarge', 'backend': 'AWS'})
  c5_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c5.large', 'backend': 'AWS'})
  c5_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c5.xlarge', 'backend': 'AWS'})
  c5a_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c5a.2xlarge', 'backend': 'AWS'})
  c5a_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c5a.4xlarge', 'backend': 'AWS'})
  c5a_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c5a.large', 'backend': 'AWS'})
  c5a_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c5a.xlarge', 'backend': 'AWS'})
  c5ad_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c5ad.2xlarge', 'backend': 'AWS'})
  c5ad_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c5ad.4xlarge', 'backend': 'AWS'})
  c5ad_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c5ad.large', 'backend': 'AWS'})
  c5ad_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c5ad.xlarge', 'backend': 'AWS'})
  c5d_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c5d.2xlarge', 'backend': 'AWS'})
  c5d_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c5d.4xlarge', 'backend': 'AWS'})
  c5d_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c5d.large', 'backend': 'AWS'})
  c5d_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c5d.xlarge', 'backend': 'AWS'})
  c6g_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c6g.2xlarge', 'backend': 'AWS'})
  c6g_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c6g.4xlarge', 'backend': 'AWS'})
  c6g_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c6g.large', 'backend': 'AWS'})
  c6g_medium = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'c6g.medium', 'backend': 'AWS'})
  c6g_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c6g.xlarge', 'backend': 'AWS'})
  c6gd_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c6gd.2xlarge', 'backend': 'AWS'})
  c6gd_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c6gd.4xlarge', 'backend': 'AWS'})
  c6gd_large = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c6gd.large', 'backend': 'AWS'})
  c6gd_medium = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'c6gd.medium', 'backend': 'AWS'})
  c6gd_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c6gd.xlarge', 'backend': 'AWS'})
  f1_2xlarge = PresetMachineConfig(cpu='8000m',memory='122Gi',metadata={'api_name': 'f1.2xlarge', 'backend': 'AWS'})
  f1_4xlarge = PresetMachineConfig(cpu='16000m',memory='244Gi',metadata={'api_name': 'f1.4xlarge', 'backend': 'AWS'})
  g3_4xlarge = PresetMachineConfig(cpu='16000m',memory='122Gi',gpu='1',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'g3.4xlarge', 'backend': 'AWS'})
  g4ad_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',gpu='1',gpu_name='amd-radeon-pro-v520',metadata={'api_name': 'g4ad.2xlarge', 'backend': 'AWS'})
  g4ad_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',gpu='1',gpu_name='amd-radeon-pro-v520',metadata={'api_name': 'g4ad.4xlarge', 'backend': 'AWS'})
  g4ad_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',gpu='1',gpu_name='amd-radeon-pro-v520',metadata={'api_name': 'g4ad.xlarge', 'backend': 'AWS'})
  g5_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',gpu='1',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.2xlarge', 'backend': 'AWS'})
  g5_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',gpu='1',gpu_name='nvidia-a10g',metadata={'api_name': 'g5.xlarge', 'backend': 'AWS'})
  g5g_2xlarge = PresetMachineConfig(cpu='8000m',memory='16Gi',gpu='1',gpu_name='nvidia-t4g-tensor-core',metadata={'api_name': 'g5g.2xlarge', 'backend': 'AWS'})
  g5g_4xlarge = PresetMachineConfig(cpu='16000m',memory='32Gi',gpu='1',gpu_name='nvidia-t4g-tensor-core',metadata={'api_name': 'g5g.4xlarge', 'backend': 'AWS'})
  g5g_xlarge = PresetMachineConfig(cpu='4000m',memory='8Gi',gpu='1',gpu_name='nvidia-t4g-tensor-core',metadata={'api_name': 'g5g.xlarge', 'backend': 'AWS'})
  h1_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'h1.2xlarge', 'backend': 'AWS'})
  h1_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'h1.4xlarge', 'backend': 'AWS'})
  i3_2xlarge = PresetMachineConfig(cpu='8000m',memory='61Gi',metadata={'api_name': 'i3.2xlarge', 'backend': 'AWS'})
  i3_4xlarge = PresetMachineConfig(cpu='16000m',memory='122Gi',metadata={'api_name': 'i3.4xlarge', 'backend': 'AWS'})
  i4i_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'i4i.large', 'backend': 'AWS'})
  i4i_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'i4i.xlarge', 'backend': 'AWS'})
  m5_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5.2xlarge', 'backend': 'AWS'})
  m5_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm5.4xlarge', 'backend': 'AWS'})
  m5_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5.large', 'backend': 'AWS'})
  m5_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5.xlarge', 'backend': 'AWS'})
  m5a_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5a.2xlarge', 'backend': 'AWS'})
  m5a_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm5a.4xlarge', 'backend': 'AWS'})
  m5a_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm5a.8xlarge', 'backend': 'AWS'})
  m5a_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5a.large', 'backend': 'AWS'})
  m5a_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5a.xlarge', 'backend': 'AWS'})
  m5ad_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5ad.2xlarge', 'backend': 'AWS'})
  m5ad_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm5ad.4xlarge', 'backend': 'AWS'})
  m5ad_8xlarge = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'm5ad.8xlarge', 'backend': 'AWS'})
  m5ad_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5ad.large', 'backend': 'AWS'})
  m5ad_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5ad.xlarge', 'backend': 'AWS'})
  m5d_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm5d.2xlarge', 'backend': 'AWS'})
  m5d_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm5d.4xlarge', 'backend': 'AWS'})
  m5d_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm5d.large', 'backend': 'AWS'})
  m5d_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm5d.xlarge', 'backend': 'AWS'})
  m6g_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm6g.2xlarge', 'backend': 'AWS'})
  m6g_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm6g.4xlarge', 'backend': 'AWS'})
  m6g_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm6g.large', 'backend': 'AWS'})
  m6g_medium = PresetMachineConfig(cpu='1000m',memory='4Gi',metadata={'api_name': 'm6g.medium', 'backend': 'AWS'})
  m6g_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm6g.xlarge', 'backend': 'AWS'})
  m6gd_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm6gd.2xlarge', 'backend': 'AWS'})
  m6gd_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm6gd.4xlarge', 'backend': 'AWS'})
  m6gd_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm6gd.large', 'backend': 'AWS'})
  m6gd_medium = PresetMachineConfig(cpu='1000m',memory='4Gi',metadata={'api_name': 'm6gd.medium', 'backend': 'AWS'})
  m6gd_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm6gd.xlarge', 'backend': 'AWS'})
  p3_2xlarge = PresetMachineConfig(cpu='8000m',memory='61Gi',gpu='1',gpu_name='nvidia-tesla-v100',metadata={'api_name': 'p3.2xlarge', 'backend': 'AWS'})
  r4_2xlarge = PresetMachineConfig(cpu='8000m',memory='61Gi',metadata={'api_name': 'r4.2xlarge', 'backend': 'AWS'})
  r4_4xlarge = PresetMachineConfig(cpu='16000m',memory='122Gi',metadata={'api_name': 'r4.4xlarge', 'backend': 'AWS'})
  r5_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5.2xlarge', 'backend': 'AWS'})
  r5_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5.4xlarge', 'backend': 'AWS'})
  r5_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5.large', 'backend': 'AWS'})
  r5_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5.xlarge', 'backend': 'AWS'})
  r5a_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5a.2xlarge', 'backend': 'AWS'})
  r5a_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5a.4xlarge', 'backend': 'AWS'})
  r5a_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5a.8xlarge', 'backend': 'AWS'})
  r5a_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5a.large', 'backend': 'AWS'})
  r5a_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5a.xlarge', 'backend': 'AWS'})
  r5ad_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5ad.2xlarge', 'backend': 'AWS'})
  r5ad_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5ad.4xlarge', 'backend': 'AWS'})
  r5ad_8xlarge = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'r5ad.8xlarge', 'backend': 'AWS'})
  r5ad_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5ad.large', 'backend': 'AWS'})
  r5ad_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5ad.xlarge', 'backend': 'AWS'})
  r5b_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5b.2xlarge', 'backend': 'AWS'})
  r5b_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5b.4xlarge', 'backend': 'AWS'})
  r5b_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5b.large', 'backend': 'AWS'})
  r5b_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5b.xlarge', 'backend': 'AWS'})
  r5d_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r5d.2xlarge', 'backend': 'AWS'})
  r5d_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r5d.4xlarge', 'backend': 'AWS'})
  r5d_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r5d.large', 'backend': 'AWS'})
  r5d_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r5d.xlarge', 'backend': 'AWS'})
  r6g_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r6g.2xlarge', 'backend': 'AWS'})
  r6g_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r6g.4xlarge', 'backend': 'AWS'})
  r6g_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r6g.large', 'backend': 'AWS'})
  r6g_medium = PresetMachineConfig(cpu='1000m',memory='8Gi',metadata={'api_name': 'r6g.medium', 'backend': 'AWS'})
  r6g_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r6g.xlarge', 'backend': 'AWS'})
  r6gd_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'r6gd.2xlarge', 'backend': 'AWS'})
  r6gd_4xlarge = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'r6gd.4xlarge', 'backend': 'AWS'})
  r6gd_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'r6gd.large', 'backend': 'AWS'})
  r6gd_medium = PresetMachineConfig(cpu='1000m',memory='8Gi',metadata={'api_name': 'r6gd.medium', 'backend': 'AWS'})
  r6gd_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'r6gd.xlarge', 'backend': 'AWS'})
  x1e_2xlarge = PresetMachineConfig(cpu='8000m',memory='244Gi',metadata={'api_name': 'x1e.2xlarge', 'backend': 'AWS'})
  x1e_4xlarge = PresetMachineConfig(cpu='16000m',memory='488Gi',metadata={'api_name': 'x1e.4xlarge', 'backend': 'AWS'})
  x1e_8xlarge = PresetMachineConfig(cpu='32000m',memory='976Gi',metadata={'api_name': 'x1e.8xlarge', 'backend': 'AWS'})
  x1e_xlarge = PresetMachineConfig(cpu='4000m',memory='122Gi',metadata={'api_name': 'x1e.xlarge', 'backend': 'AWS'})
  x2gd_2xlarge = PresetMachineConfig(cpu='8000m',memory='128Gi',metadata={'api_name': 'x2gd.2xlarge', 'backend': 'AWS'})
  x2gd_4xlarge = PresetMachineConfig(cpu='16000m',memory='256Gi',metadata={'api_name': 'x2gd.4xlarge', 'backend': 'AWS'})
  x2gd_large = PresetMachineConfig(cpu='2000m',memory='32Gi',metadata={'api_name': 'x2gd.large', 'backend': 'AWS'})
  x2gd_medium = PresetMachineConfig(cpu='1000m',memory='16Gi',metadata={'api_name': 'x2gd.medium', 'backend': 'AWS'})
  x2gd_xlarge = PresetMachineConfig(cpu='4000m',memory='64Gi',metadata={'api_name': 'x2gd.xlarge', 'backend': 'AWS'})
  z1d_2xlarge = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'z1d.2xlarge', 'backend': 'AWS'})
  z1d_3xlarge = PresetMachineConfig(cpu='12000m',memory='96Gi',metadata={'api_name': 'z1d.3xlarge', 'backend': 'AWS'})
  z1d_large = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'z1d.large', 'backend': 'AWS'})
  z1d_xlarge = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'z1d.xlarge', 'backend': 'AWS'})
  c1_xlarge = PresetMachineConfig(cpu='8000m',memory='7Gi',metadata={'api_name': 'c1.xlarge', 'backend': 'AWS'})
  c3_2xlarge = PresetMachineConfig(cpu='8000m',memory='15Gi',metadata={'api_name': 'c3.2xlarge', 'backend': 'AWS'})
  c3_4xlarge = PresetMachineConfig(cpu='16000m',memory='30Gi',metadata={'api_name': 'c3.4xlarge', 'backend': 'AWS'})
  c4_2xlarge = PresetMachineConfig(cpu='8000m',memory='15Gi',metadata={'api_name': 'c4.2xlarge', 'backend': 'AWS'})
  c4_4xlarge = PresetMachineConfig(cpu='16000m',memory='30Gi',metadata={'api_name': 'c4.4xlarge', 'backend': 'AWS'})
  d2_2xlarge = PresetMachineConfig(cpu='8000m',memory='61Gi',metadata={'api_name': 'd2.2xlarge', 'backend': 'AWS'})
  d2_4xlarge = PresetMachineConfig(cpu='16000m',memory='122Gi',metadata={'api_name': 'd2.4xlarge', 'backend': 'AWS'})
  i2_2xlarge = PresetMachineConfig(cpu='8000m',memory='61Gi',metadata={'api_name': 'i2.2xlarge', 'backend': 'AWS'})
  i2_4xlarge = PresetMachineConfig(cpu='16000m',memory='122Gi',metadata={'api_name': 'i2.4xlarge', 'backend': 'AWS'})
  m1_xlarge = PresetMachineConfig(cpu='4000m',memory='15Gi',metadata={'api_name': 'm1.xlarge', 'backend': 'AWS'})
  m3_2xlarge = PresetMachineConfig(cpu='8000m',memory='30Gi',metadata={'api_name': 'm3.2xlarge', 'backend': 'AWS'})
  m3_xlarge = PresetMachineConfig(cpu='4000m',memory='15Gi',metadata={'api_name': 'm3.xlarge', 'backend': 'AWS'})
  m4_2xlarge = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'm4.2xlarge', 'backend': 'AWS'})
  m4_4xlarge = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'm4.4xlarge', 'backend': 'AWS'})
  m4_xlarge = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'm4.xlarge', 'backend': 'AWS'})
  p2_xlarge = PresetMachineConfig(cpu='4000m',memory='61Gi',gpu='1',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'p2.xlarge', 'backend': 'AWS'})
  r3_2xlarge = PresetMachineConfig(cpu='8000m',memory='61Gi',metadata={'api_name': 'r3.2xlarge', 'backend': 'AWS'})
  r3_4xlarge = PresetMachineConfig(cpu='16000m',memory='122Gi',metadata={'api_name': 'r3.4xlarge', 'backend': 'AWS'})
  g2_8xlarge = PresetMachineConfig(cpu='32000m',memory='60Gi',gpu='4',gpu_name='nvidia-grid-k520',metadata={'api_name': 'g2.8xlarge', 'backend': 'AWS'})
  g2_2xlarge = PresetMachineConfig(cpu='8000m',memory='15Gi',gpu='1',gpu_name='nvidia-grid-k520',metadata={'api_name': 'g2.2xlarge', 'backend': 'AWS'})
  m4_large = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'm4.large', 'backend': 'AWS'})
  i2_large = PresetMachineConfig(cpu='2000m',memory='15Gi',metadata={'api_name': 'i2.large', 'backend': 'AWS'})

# Computer types in Google Cloud Platform
class GCP:
  """
  Almost all the machines available in GCP are listed here.

  For more information please refer the [GCP documentation](https://cloud.google.com/compute/docs/machine-types).
  """
  e2_micro = PresetMachineConfig(cpu='2000m',memory='1Gi',metadata={'api_name': 'e2-micro', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_2 = PresetMachineConfig(cpu='2000m',memory='2Gi',metadata={'api_name': 'n2-highcpu-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_2 = PresetMachineConfig(cpu='2000m',memory='2Gi',metadata={'api_name': 'n2d-highcpu-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highcpu_2 = PresetMachineConfig(cpu='2000m',memory='2Gi',metadata={'api_name': 'e2-highcpu-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_small = PresetMachineConfig(cpu='2000m',memory='2Gi',metadata={'api_name': 'e2-small', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_4 = PresetMachineConfig(cpu='4000m',memory='4Gi',metadata={'api_name': 'n2-highcpu-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_4 = PresetMachineConfig(cpu='4000m',memory='4Gi',metadata={'api_name': 'n2d-highcpu-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highcpu_4 = PresetMachineConfig(cpu='4000m',memory='4Gi',metadata={'api_name': 'e2-highcpu-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_medium = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'e2-medium', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highcpu_2 = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'c2d-highcpu-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_1 = PresetMachineConfig(cpu='1000m',memory='4Gi',metadata={'api_name': 't2d-standard-1', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_1 = PresetMachineConfig(cpu='1000m',memory='4Gi',metadata={'api_name': 't2a-standard-1', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_standard_2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'n2-standard-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_8 = PresetMachineConfig(cpu='8000m',memory='8Gi',metadata={'api_name': 'n2-highcpu-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'n2d-standard-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_8 = PresetMachineConfig(cpu='8000m',memory='8Gi',metadata={'api_name': 'n2d-highcpu-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highcpu_8 = PresetMachineConfig(cpu='8000m',memory='8Gi',metadata={'api_name': 'e2-highcpu-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_standard_2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'e2-standard-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_standard_2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'c2d-standard-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highcpu_4 = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'c2d-highcpu-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 't2d-standard-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 't2a-standard-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_2 = PresetMachineConfig(cpu='2000m',memory='13Gi',metadata={'api_name': 'n1-highmem-2', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n1_standard_4 = PresetMachineConfig(cpu='4000m',memory='15Gi',metadata={'api_name': 'n1-standard-4', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'n2-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_2 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'n2-highmem-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_16 = PresetMachineConfig(cpu='16000m',memory='16Gi',metadata={'api_name': 'n2-highcpu-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'n2d-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_2 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'n2d-highmem-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_16 = PresetMachineConfig(cpu='16000m',memory='16Gi',metadata={'api_name': 'n2d-highcpu-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highcpu_16 = PresetMachineConfig(cpu='16000m',memory='16Gi',metadata={'api_name': 'e2-highcpu-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highmem_2 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'e2-highmem-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'e2-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'c2-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'c2d-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highcpu_8 = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'c2d-highcpu-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_2 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'c2d-highmem-2', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 't2d-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 't2a-standard-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_4 = PresetMachineConfig(cpu='4000m',memory='26Gi',metadata={'api_name': 'n1-highmem-4', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n1_standard_8 = PresetMachineConfig(cpu='8000m',memory='30Gi',metadata={'api_name': 'n1-standard-8', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'n2-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'n2-highmem-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_32 = PresetMachineConfig(cpu='32000m',memory='32Gi',metadata={'api_name': 'n2-highcpu-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'n2d-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'n2d-highmem-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_32 = PresetMachineConfig(cpu='32000m',memory='32Gi',metadata={'api_name': 'n2d-highcpu-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highcpu_32 = PresetMachineConfig(cpu='32000m',memory='32Gi',metadata={'api_name': 'e2-highcpu-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highmem_4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'e2-highmem-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'e2-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'c2-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'c2d-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highcpu_16 = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'c2d-highcpu-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'c2d-highmem-4', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 't2d-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_8 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 't2a-standard-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_48 = PresetMachineConfig(cpu='48000m',memory='48Gi',metadata={'api_name': 'n2-highcpu-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_48 = PresetMachineConfig(cpu='48000m',memory='48Gi',metadata={'api_name': 'n2d-highcpu-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_8 = PresetMachineConfig(cpu='8000m',memory='52Gi',metadata={'api_name': 'n1-highmem-8', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n1_standard_16 = PresetMachineConfig(cpu='16000m',memory='60Gi',metadata={'api_name': 'n1-standard-16', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'n2-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_8 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'n2-highmem-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_64 = PresetMachineConfig(cpu='64000m',memory='64Gi',metadata={'api_name': 'n2-highcpu-64', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'n2d-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_8 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'n2d-highmem-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_64 = PresetMachineConfig(cpu='64000m',memory='64Gi',metadata={'api_name': 'n2d-highcpu-64', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highmem_8 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'e2-highmem-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'e2-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'c2-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'c2d-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highcpu_32 = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'c2d-highcpu-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_8 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'c2d-highmem-8', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 't2d-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_16 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 't2a-standard-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highcpu_80 = PresetMachineConfig(cpu='80000m',memory='80Gi',metadata={'api_name': 'n2-highcpu-80', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_80 = PresetMachineConfig(cpu='80000m',memory='80Gi',metadata={'api_name': 'n2d-highcpu-80', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  a2_highgpu_1g = PresetMachineConfig(cpu='12000m',memory='85Gi',metadata={'api_name': 'a2-highgpu-1g', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_highcpu_96 = PresetMachineConfig(cpu='96000m',memory='96Gi',metadata={'api_name': 'n2-highcpu-96', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_96 = PresetMachineConfig(cpu='96000m',memory='96Gi',metadata={'api_name': 'n2d-highcpu-96', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_16 = PresetMachineConfig(cpu='16000m',memory='104Gi',metadata={'api_name': 'n1-highmem-16', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  c2d_highcpu_56 = PresetMachineConfig(cpu='56000m',memory='112Gi',metadata={'api_name': 'c2d-highcpu-56', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_standard_32 = PresetMachineConfig(cpu='32000m',memory='120Gi',metadata={'api_name': 'n1-standard-32', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  c2_standard_30 = PresetMachineConfig(cpu='30000m',memory='120Gi',metadata={'api_name': 'c2-standard-30', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_standard_32 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'n2-standard-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_16 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'n2-highmem-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_32 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'n2d-standard-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_16 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'n2d-highmem-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highcpu_128 = PresetMachineConfig(cpu='128000m',memory='128Gi',metadata={'api_name': 'n2d-highcpu-128', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_highmem_16 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'e2-highmem-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  e2_standard_32 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'e2-standard-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_standard_32 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'c2d-standard-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_16 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'c2d-highmem-16', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_32 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 't2d-standard-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_32 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 't2a-standard-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  a2_highgpu_2g = PresetMachineConfig(cpu='24000m',memory='170Gi',metadata={'api_name': 'a2-highgpu-2g', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_standard_48 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'n2-standard-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_48 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'n2d-standard-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_48 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 't2d-standard-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2a_standard_48 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 't2a-standard-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_32 = PresetMachineConfig(cpu='32000m',memory='208Gi',metadata={'api_name': 'n1-highmem-32', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2d_highcpu_224 = PresetMachineConfig(cpu='224000m',memory='224Gi',metadata={'api_name': 'n2d-highcpu-224', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_standard_56 = PresetMachineConfig(cpu='56000m',memory='224Gi',metadata={'api_name': 'c2d-standard-56', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highcpu_112 = PresetMachineConfig(cpu='112000m',memory='224Gi',metadata={'api_name': 'c2d-highcpu-112', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_standard_64 = PresetMachineConfig(cpu='64000m',memory='240Gi',metadata={'api_name': 'n1-standard-64', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  c2_standard_60 = PresetMachineConfig(cpu='60000m',memory='240Gi',metadata={'api_name': 'c2-standard-60', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  t2d_standard_60 = PresetMachineConfig(cpu='60000m',memory='240Gi',metadata={'api_name': 't2d-standard-60', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_standard_64 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'n2-standard-64', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_32 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'n2-highmem-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_64 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'n2d-standard-64', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_32 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'n2d-highmem-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_32 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'c2d-highmem-32', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_standard_80 = PresetMachineConfig(cpu='80000m',memory='320Gi',metadata={'api_name': 'n2-standard-80', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_80 = PresetMachineConfig(cpu='80000m',memory='320Gi',metadata={'api_name': 'n2d-standard-80', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  a2_highgpu_4g = PresetMachineConfig(cpu='48000m',memory='340Gi',metadata={'api_name': 'a2-highgpu-4g', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n1_standard_96 = PresetMachineConfig(cpu='96000m',memory='360Gi',metadata={'api_name': 'n1-standard-96', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_standard_96 = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'n2-standard-96', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_48 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'n2-highmem-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_96 = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'n2d-standard-96', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_48 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'n2d-highmem-48', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_64 = PresetMachineConfig(cpu='64000m',memory='416Gi',metadata={'api_name': 'n1-highmem-64', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  c2d_standard_112 = PresetMachineConfig(cpu='112000m',memory='448Gi',metadata={'api_name': 'c2d-standard-112', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_56 = PresetMachineConfig(cpu='56000m',memory='448Gi',metadata={'api_name': 'c2d-highmem-56', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_standard_128 = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'n2-standard-128', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_64 = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'n2-highmem-64', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_128 = PresetMachineConfig(cpu='128000m',memory='512Gi',metadata={'api_name': 'n2d-standard-128', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_64 = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'n2d-highmem-64', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n1_highmem_96 = PresetMachineConfig(cpu='96000m',memory='624Gi',metadata={'api_name': 'n1-highmem-96', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_highmem_80 = PresetMachineConfig(cpu='80000m',memory='640Gi',metadata={'api_name': 'n2-highmem-80', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_80 = PresetMachineConfig(cpu='80000m',memory='640Gi',metadata={'api_name': 'n2d-highmem-80', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  a2_highgpu_8g = PresetMachineConfig(cpu='96000m',memory='680Gi',metadata={'api_name': 'a2-highgpu-8g', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  n2_highmem_96 = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'n2-highmem-96', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_highmem_96 = PresetMachineConfig(cpu='96000m',memory='768Gi',metadata={'api_name': 'n2d-highmem-96', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2_highmem_128 = PresetMachineConfig(cpu='128000m',memory='864Gi',metadata={'api_name': 'n2-highmem-128', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  n2d_standard_224 = PresetMachineConfig(cpu='224000m',memory='896Gi',metadata={'api_name': 'n2d-standard-224', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  c2d_highmem_112 = PresetMachineConfig(cpu='112000m',memory='896Gi',metadata={'api_name': 'c2d-highmem-112', 'backend': 'GCP', 'gpu_comments': 'Not supported'})
  m1_ultramem_40 = PresetMachineConfig(cpu='40000m',memory='961Gi',metadata={'api_name': 'm1-ultramem-40', 'backend': 'GCP', 'gpu_comments': 'Unknown'})
  a2_megagpu_16g = PresetMachineConfig(cpu='96000m',memory='1360Gi',metadata={'api_name': 'a2-megagpu-16g', 'backend': 'GCP', 'gpu_comments': 'Supported'})
  m1_ultramem_80 = PresetMachineConfig(cpu='80000m',memory='1922Gi',metadata={'api_name': 'm1-ultramem-80', 'backend': 'GCP', 'gpu_comments': 'Unknown'})
  m1_ultramem_160 = PresetMachineConfig(cpu='160000m',memory='3844Gi',metadata={'api_name': 'm1-ultramem-160', 'backend': 'GCP', 'gpu_comments': 'Unknown'})
  m2_megamem_416 = PresetMachineConfig(cpu='416000m',memory='5888Gi',metadata={'api_name': 'm2-megamem-416', 'backend': 'GCP', 'gpu_comments': 'Unknown'})
  m2_ultramem_208 = PresetMachineConfig(cpu='208000m',memory='5888Gi',metadata={'api_name': 'm2-ultramem-208', 'backend': 'GCP', 'gpu_comments': 'Unknown'})
  m2_ultramem_416 = PresetMachineConfig(cpu='416000m',memory='11776Gi',metadata={'api_name': 'm2-ultramem-416', 'backend': 'GCP', 'gpu_comments': 'Unknown'})

# Computer types in Microsoft Azure
class MSAZ:
  """
  Almost all the machines available in Microsoft Azure are listed here.

  For more information please refer the [Microsoft Azure documentation](https://docs.microsoft.com/en-us/azure/virtual-machines/sizes-general)
  """
  M416ms_v2 = PresetMachineConfig(cpu='416000m',memory='11400Gi',metadata={'api_name': 'M416ms v2', 'backend': 'MSAZ'})
  M208ms_v2 = PresetMachineConfig(cpu='208000m',memory='5700Gi',metadata={'api_name': 'M208ms v2', 'backend': 'MSAZ'})
  M416s_v2 = PresetMachineConfig(cpu='416000m',memory='5700Gi',metadata={'api_name': 'M416s v2', 'backend': 'MSAZ'})
  M192idms_v2 = PresetMachineConfig(cpu='192000m',memory='4096Gi',metadata={'api_name': 'M192idms v2', 'backend': 'MSAZ'})
  M192ims_v2 = PresetMachineConfig(cpu='192000m',memory='4096Gi',metadata={'api_name': 'M192ims v2', 'backend': 'MSAZ'})
  M128dms_v2 = PresetMachineConfig(cpu='128000m',memory='3892Gi',metadata={'api_name': 'M128dms v2', 'backend': 'MSAZ'})
  M128m = PresetMachineConfig(cpu='128000m',memory='3892Gi',metadata={'api_name': 'M128m', 'backend': 'MSAZ'})
  M128ms_v2 = PresetMachineConfig(cpu='128000m',memory='3892Gi',metadata={'api_name': 'M128ms v2', 'backend': 'MSAZ'})
  M208s_v2 = PresetMachineConfig(cpu='208000m',memory='2850Gi',metadata={'api_name': 'M208s v2', 'backend': 'MSAZ'})
  M128ds_v2 = PresetMachineConfig(cpu='128000m',memory='2048Gi',metadata={'api_name': 'M128ds v2', 'backend': 'MSAZ'})
  M192ids_v2 = PresetMachineConfig(cpu='192000m',memory='2048Gi',metadata={'api_name': 'M192ids v2', 'backend': 'MSAZ'})
  M128 = PresetMachineConfig(cpu='128000m',memory='2048Gi',metadata={'api_name': 'M128', 'backend': 'MSAZ'})
  M128s = PresetMachineConfig(cpu='128000m',memory='2048Gi',metadata={'api_name': 'M128s', 'backend': 'MSAZ'})
  M128s_v2 = PresetMachineConfig(cpu='128000m',memory='2048Gi',metadata={'api_name': 'M128s v2', 'backend': 'MSAZ'})
  M192is_v2 = PresetMachineConfig(cpu='192000m',memory='2048Gi',metadata={'api_name': 'M192is v2', 'backend': 'MSAZ'})
  M64dms_v2 = PresetMachineConfig(cpu='64000m',memory='1792Gi',metadata={'api_name': 'M64dms v2', 'backend': 'MSAZ'})
  M64m = PresetMachineConfig(cpu='64000m',memory='1792Gi',metadata={'api_name': 'M64m', 'backend': 'MSAZ'})
  M64ms = PresetMachineConfig(cpu='64000m',memory='1792Gi',metadata={'api_name': 'M64ms', 'backend': 'MSAZ'})
  M64ms_v2 = PresetMachineConfig(cpu='64000m',memory='1792Gi',metadata={'api_name': 'M64ms v2', 'backend': 'MSAZ'})
  M64ds_v2 = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'M64ds v2', 'backend': 'MSAZ'})
  M64 = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'M64', 'backend': 'MSAZ'})
  M64s = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'M64s', 'backend': 'MSAZ'})
  M64s_v2 = PresetMachineConfig(cpu='64000m',memory='1024Gi',metadata={'api_name': 'M64s v2', 'backend': 'MSAZ'})
  M32dms_v2 = PresetMachineConfig(cpu='32000m',memory='875Gi',metadata={'api_name': 'M32dms v2', 'backend': 'MSAZ'})
  M32ms = PresetMachineConfig(cpu='32000m',memory='875Gi',metadata={'api_name': 'M32ms', 'backend': 'MSAZ'})
  M32ms_v2 = PresetMachineConfig(cpu='32000m',memory='875Gi',metadata={'api_name': 'M32ms v2', 'backend': 'MSAZ'})
  E96a_v4 = PresetMachineConfig(cpu='96000m',memory='672Gi',metadata={'api_name': 'E96a v4', 'backend': 'MSAZ'})
  E96as_v4 = PresetMachineConfig(cpu='96000m',memory='672Gi',metadata={'api_name': 'E96as v4', 'backend': 'MSAZ'})
  NP40s = PresetMachineConfig(cpu='40000m',memory='672Gi',metadata={'api_name': 'NP40s', 'backend': 'MSAZ'})
  L80s_v2 = PresetMachineConfig(cpu='80000m',memory='640Gi',metadata={'api_name': 'L80s v2', 'backend': 'MSAZ'})
  E64a_v4 = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'E64a v4', 'backend': 'MSAZ'})
  E64as_v4 = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'E64as v4', 'backend': 'MSAZ'})
  L64s_v2 = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'L64s v2', 'backend': 'MSAZ'})
  M64ls = PresetMachineConfig(cpu='64000m',memory='512Gi',metadata={'api_name': 'M64ls', 'backend': 'MSAZ'})
  E64d_v4 = PresetMachineConfig(cpu='64000m',memory='504Gi',metadata={'api_name': 'E64d v4', 'backend': 'MSAZ'})
  E64ds_v4 = PresetMachineConfig(cpu='64000m',memory='504Gi',metadata={'api_name': 'E64ds v4', 'backend': 'MSAZ'})
  E80ids_v4 = PresetMachineConfig(cpu='80000m',memory='504Gi',metadata={'api_name': 'E80ids v4', 'backend': 'MSAZ'})
  E64s_v4 = PresetMachineConfig(cpu='64000m',memory='504Gi',metadata={'api_name': 'E64s v4', 'backend': 'MSAZ'})
  E80is_v4 = PresetMachineConfig(cpu='80000m',memory='504Gi',metadata={'api_name': 'E80is v4', 'backend': 'MSAZ'})
  E64_v4 = PresetMachineConfig(cpu='64000m',memory='504Gi',metadata={'api_name': 'E64 v4', 'backend': 'MSAZ'})
  G5 = PresetMachineConfig(cpu='32000m',memory='448Gi',metadata={'api_name': 'G5', 'backend': 'MSAZ'})
  Gs5 = PresetMachineConfig(cpu='32000m',memory='448Gi',metadata={'api_name': 'Gs5', 'backend': 'MSAZ'})
  NC24s_v2 = PresetMachineConfig(cpu='24000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-p100-gpu',metadata={'api_name': 'NC24s v2', 'backend': 'MSAZ'})
  NC24rs_v2 = PresetMachineConfig(cpu='24000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-p100-gpu',metadata={'api_name': 'NC24rs v2', 'backend': 'MSAZ'})
  NC24s_v3 = PresetMachineConfig(cpu='24000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-v100-gpu',metadata={'api_name': 'NC24s v3', 'backend': 'MSAZ'})
  NC24rs_v3 = PresetMachineConfig(cpu='24000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-v100-gpu',metadata={'api_name': 'NC24rs v3', 'backend': 'MSAZ'})
  ND24rs = PresetMachineConfig(cpu='24000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-p40',metadata={'api_name': 'ND24rs', 'backend': 'MSAZ'})
  ND24s = PresetMachineConfig(cpu='24000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-p40',metadata={'api_name': 'ND24s', 'backend': 'MSAZ'})
  NV48s_v3 = PresetMachineConfig(cpu='48000m',memory='448Gi',gpu='4',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'NV48s v3', 'backend': 'MSAZ'})
  M16ms = PresetMachineConfig(cpu='16000m',memory='437.5Gi',metadata={'api_name': 'M16ms', 'backend': 'MSAZ'})
  E64is_v3 = PresetMachineConfig(cpu='64000m',memory='432Gi',metadata={'api_name': 'E64is v3', 'backend': 'MSAZ'})
  E64s_v3 = PresetMachineConfig(cpu='64000m',memory='432Gi',metadata={'api_name': 'E64s v3', 'backend': 'MSAZ'})
  E64i_v3 = PresetMachineConfig(cpu='64000m',memory='432Gi',metadata={'api_name': 'E64i v3', 'backend': 'MSAZ'})
  E64_v3 = PresetMachineConfig(cpu='64000m',memory='432Gi',metadata={'api_name': 'E64 v3', 'backend': 'MSAZ'})
  D96a_v4 = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'D96a v4', 'backend': 'MSAZ'})
  D96as_v4 = PresetMachineConfig(cpu='96000m',memory='384Gi',metadata={'api_name': 'D96as v4', 'backend': 'MSAZ'})
  E48a_v4 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48a v4', 'backend': 'MSAZ'})
  E48as_v4 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48as v4', 'backend': 'MSAZ'})
  E48d_v4 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48d v4', 'backend': 'MSAZ'})
  E48ds_v4 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48ds v4', 'backend': 'MSAZ'})
  E48s_v3 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48s v3', 'backend': 'MSAZ'})
  E48s_v4 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48s v4', 'backend': 'MSAZ'})
  E48_v3 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48 v3', 'backend': 'MSAZ'})
  E48_v4 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'E48 v4', 'backend': 'MSAZ'})
  L48s_v2 = PresetMachineConfig(cpu='48000m',memory='384Gi',metadata={'api_name': 'L48s v2', 'backend': 'MSAZ'})
  HC44rs = PresetMachineConfig(cpu='44000m',memory='352Gi',metadata={'api_name': 'HC44rs', 'backend': 'MSAZ'})
  NP20s = PresetMachineConfig(cpu='20000m',memory='336Gi',metadata={'api_name': 'NP20s', 'backend': 'MSAZ'})
  D64a_v4 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64a v4', 'backend': 'MSAZ'})
  D64as_v4 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64as v4', 'backend': 'MSAZ'})
  D64d_v4 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64d v4', 'backend': 'MSAZ'})
  D64ds_v4 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64ds v4', 'backend': 'MSAZ'})
  D64s_v3 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64s v3', 'backend': 'MSAZ'})
  D64s_v4 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64s v4', 'backend': 'MSAZ'})
  D64_v3 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64 v3', 'backend': 'MSAZ'})
  D64_v4 = PresetMachineConfig(cpu='64000m',memory='256Gi',metadata={'api_name': 'D64 v4', 'backend': 'MSAZ'})
  E32a_v4 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32a v4', 'backend': 'MSAZ'})
  E32as_v4 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32as v4', 'backend': 'MSAZ'})
  E32d_v4 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32d v4', 'backend': 'MSAZ'})
  E32ds_v4 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32ds v4', 'backend': 'MSAZ'})
  E32s_v3 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32s v3', 'backend': 'MSAZ'})
  E32s_v4 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32s v4', 'backend': 'MSAZ'})
  E32_v3 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32 v3', 'backend': 'MSAZ'})
  E32_v4 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'E32 v4', 'backend': 'MSAZ'})
  L32s = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'L32s', 'backend': 'MSAZ'})
  L32s_v2 = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'L32s v2', 'backend': 'MSAZ'})
  M32ls = PresetMachineConfig(cpu='32000m',memory='256Gi',metadata={'api_name': 'M32ls', 'backend': 'MSAZ'})
  HB60rs = PresetMachineConfig(cpu='60000m',memory='240Gi',metadata={'api_name': 'HB60rs', 'backend': 'MSAZ'})
  G4 = PresetMachineConfig(cpu='16000m',memory='224Gi',metadata={'api_name': 'G4', 'backend': 'MSAZ'})
  Gs4 = PresetMachineConfig(cpu='16000m',memory='224Gi',metadata={'api_name': 'Gs4', 'backend': 'MSAZ'})
  H16m = PresetMachineConfig(cpu='16000m',memory='224Gi',metadata={'api_name': 'H16m', 'backend': 'MSAZ'})
  H16mr = PresetMachineConfig(cpu='16000m',memory='224Gi',metadata={'api_name': 'H16mr', 'backend': 'MSAZ'})
  NC24 = PresetMachineConfig(cpu='24000m',memory='224Gi',gpu='4',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'NC24', 'backend': 'MSAZ'})
  NC24r = PresetMachineConfig(cpu='24000m',memory='224Gi',gpu='4',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'NC24r', 'backend': 'MSAZ'})
  NC12s_v2 = PresetMachineConfig(cpu='12000m',memory='224Gi',gpu='2',gpu_name='nvidia-tesla-p100-gpu',metadata={'api_name': 'NC12s v2', 'backend': 'MSAZ'})
  NC12s_v3 = PresetMachineConfig(cpu='12000m',memory='224Gi',gpu='2',gpu_name='nvidia-tesla-v100-gpu',metadata={'api_name': 'NC12s v3', 'backend': 'MSAZ'})
  ND12s = PresetMachineConfig(cpu='12000m',memory='224Gi',gpu='2',gpu_name='nvidia-tesla-p40',metadata={'api_name': 'ND12s', 'backend': 'MSAZ'})
  NV24 = PresetMachineConfig(cpu='24000m',memory='224Gi',gpu='4',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'NV24', 'backend': 'MSAZ'})
  NV24s_v3 = PresetMachineConfig(cpu='24000m',memory='224Gi',gpu='2',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'NV24s v3', 'backend': 'MSAZ'})
  M8ms = PresetMachineConfig(cpu='8000m',memory='218.75Gi',metadata={'api_name': 'M8ms', 'backend': 'MSAZ'})
  D48a_v4 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48a v4', 'backend': 'MSAZ'})
  D48as_v4 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48as v4', 'backend': 'MSAZ'})
  D48d_v4 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48d v4', 'backend': 'MSAZ'})
  D48ds_v4 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48ds v4', 'backend': 'MSAZ'})
  D48s_v3 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48s v3', 'backend': 'MSAZ'})
  D48s_v4 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48s v4', 'backend': 'MSAZ'})
  D48_v3 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48 v3', 'backend': 'MSAZ'})
  D48_v4 = PresetMachineConfig(cpu='48000m',memory='192Gi',metadata={'api_name': 'D48 v4', 'backend': 'MSAZ'})
  M32ts = PresetMachineConfig(cpu='32000m',memory='192Gi',metadata={'api_name': 'M32ts', 'backend': 'MSAZ'})
  NP10s = PresetMachineConfig(cpu='10000m',memory='168Gi',metadata={'api_name': 'NP10s', 'backend': 'MSAZ'})
  E20a_v4 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20a v4', 'backend': 'MSAZ'})
  E20as_v4 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20as v4', 'backend': 'MSAZ'})
  E20d_v4 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20d v4', 'backend': 'MSAZ'})
  E20ds_v4 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20ds v4', 'backend': 'MSAZ'})
  E20s_v3 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20s v3', 'backend': 'MSAZ'})
  E20s_v4 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20s v4', 'backend': 'MSAZ'})
  E20_v3 = PresetMachineConfig(cpu='20000m',memory='160Gi',metadata={'api_name': 'E20 v3', 'backend': 'MSAZ'})
  F72s_v2 = PresetMachineConfig(cpu='72000m',memory='144Gi',metadata={'api_name': 'F72s v2', 'backend': 'MSAZ'})
  DS15_v2 = PresetMachineConfig(cpu='20000m',memory='140Gi',metadata={'api_name': 'DS15 v2', 'backend': 'MSAZ'})
  D15_v2 = PresetMachineConfig(cpu='20000m',memory='140Gi',metadata={'api_name': 'D15 v2', 'backend': 'MSAZ'})
  D32a_v4 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32a v4', 'backend': 'MSAZ'})
  D32as_v4 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32as v4', 'backend': 'MSAZ'})
  D32d_v4 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32d v4', 'backend': 'MSAZ'})
  D32ds_v4 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32ds v4', 'backend': 'MSAZ'})
  D32s_v3 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32s v3', 'backend': 'MSAZ'})
  D32s_v4 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32s v4', 'backend': 'MSAZ'})
  D32_v3 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32 v3', 'backend': 'MSAZ'})
  D32_v4 = PresetMachineConfig(cpu='32000m',memory='128Gi',metadata={'api_name': 'D32 v4', 'backend': 'MSAZ'})
  E16a_v4 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16a v4', 'backend': 'MSAZ'})
  E16as_v4 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16as v4', 'backend': 'MSAZ'})
  E16d_v4 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16d v4', 'backend': 'MSAZ'})
  E16ds_v4 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16ds v4', 'backend': 'MSAZ'})
  E16s_v3 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16s v3', 'backend': 'MSAZ'})
  E16s_v4 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16s v4', 'backend': 'MSAZ'})
  E16_v3 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16 v3', 'backend': 'MSAZ'})
  E16_v4 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'E16 v4', 'backend': 'MSAZ'})
  F64s_v2 = PresetMachineConfig(cpu='64000m',memory='128Gi',metadata={'api_name': 'F64s v2', 'backend': 'MSAZ'})
  L16s = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'L16s', 'backend': 'MSAZ'})
  L16s_v2 = PresetMachineConfig(cpu='16000m',memory='128Gi',metadata={'api_name': 'L16s v2', 'backend': 'MSAZ'})
  M128ms = PresetMachineConfig(cpu='2000m',memory='128Gi',metadata={'api_name': 'M128ms', 'backend': 'MSAZ'})
  D14 = PresetMachineConfig(cpu='16000m',memory='112Gi',metadata={'api_name': 'D14', 'backend': 'MSAZ'})
  DS14_v2 = PresetMachineConfig(cpu='16000m',memory='112Gi',metadata={'api_name': 'DS14 v2', 'backend': 'MSAZ'})
  D14_v2 = PresetMachineConfig(cpu='16000m',memory='112Gi',metadata={'api_name': 'D14 v2', 'backend': 'MSAZ'})
  G3 = PresetMachineConfig(cpu='8000m',memory='112Gi',metadata={'api_name': 'G3', 'backend': 'MSAZ'})
  Gs3 = PresetMachineConfig(cpu='8000m',memory='112Gi',metadata={'api_name': 'Gs3', 'backend': 'MSAZ'})
  H16 = PresetMachineConfig(cpu='16000m',memory='112Gi',metadata={'api_name': 'H16', 'backend': 'MSAZ'})
  H8m = PresetMachineConfig(cpu='8000m',memory='112Gi',metadata={'api_name': 'H8m', 'backend': 'MSAZ'})
  H16r = PresetMachineConfig(cpu='16000m',memory='112Gi',metadata={'api_name': 'H16r', 'backend': 'MSAZ'})
  NC12 = PresetMachineConfig(cpu='12000m',memory='112Gi',gpu='2',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'NC12', 'backend': 'MSAZ'})
  NC6s_v2 = PresetMachineConfig(cpu='6000m',memory='112Gi',gpu='1',gpu_name='nvidia-tesla-p100-gpu',metadata={'api_name': 'NC6s v2', 'backend': 'MSAZ'})
  NC6s_v3 = PresetMachineConfig(cpu='6000m',memory='112Gi',gpu='1',gpu_name='nvidia-tesla-v100-gpu',metadata={'api_name': 'NC6s v3', 'backend': 'MSAZ'})
  ND6s = PresetMachineConfig(cpu='6000m',memory='112Gi',gpu='1',gpu_name='nvidia-tesla-p40',metadata={'api_name': 'ND6s', 'backend': 'MSAZ'})
  NV12 = PresetMachineConfig(cpu='12000m',memory='112Gi',gpu='2',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'NV12', 'backend': 'MSAZ'})
  NV12s_v3 = PresetMachineConfig(cpu='12000m',memory='112Gi',gpu='1',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'NV12s v3', 'backend': 'MSAZ'})
  NV32as_v4 = PresetMachineConfig(cpu='32000m',memory='112Gi',gpu='1',gpu_name='amd-radeon-instinct-mi25',metadata={'api_name': 'NV32as v4', 'backend': 'MSAZ'})
  F48s_v2 = PresetMachineConfig(cpu='48000m',memory='96Gi',metadata={'api_name': 'F48s v2', 'backend': 'MSAZ'})
  B20ms = PresetMachineConfig(cpu='20000m',memory='80Gi',metadata={'api_name': 'B20ms', 'backend': 'MSAZ'})
  A8m_v2 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'A8m v2', 'backend': 'MSAZ'})
  B16ms = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'B16ms', 'backend': 'MSAZ'})
  D16a_v4 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16a v4', 'backend': 'MSAZ'})
  D16as_v4 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16as v4', 'backend': 'MSAZ'})
  D16d_v4 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16d v4', 'backend': 'MSAZ'})
  D16ds_v4 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16ds v4', 'backend': 'MSAZ'})
  D16s_v3 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16s v3', 'backend': 'MSAZ'})
  D16s_v4 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16s v4', 'backend': 'MSAZ'})
  D16_v3 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16 v3', 'backend': 'MSAZ'})
  D16_v4 = PresetMachineConfig(cpu='16000m',memory='64Gi',metadata={'api_name': 'D16 v4', 'backend': 'MSAZ'})
  E8a_v4 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8a v4', 'backend': 'MSAZ'})
  E8as_v4 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8as v4', 'backend': 'MSAZ'})
  E8d_v4 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8d v4', 'backend': 'MSAZ'})
  E8ds_v4 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8ds v4', 'backend': 'MSAZ'})
  E8s_v3 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8s v3', 'backend': 'MSAZ'})
  E8s_v4 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8s v4', 'backend': 'MSAZ'})
  E8_v3 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8 v3', 'backend': 'MSAZ'})
  E8_v4 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'E8 v4', 'backend': 'MSAZ'})
  F32s_v2 = PresetMachineConfig(cpu='32000m',memory='64Gi',metadata={'api_name': 'F32s v2', 'backend': 'MSAZ'})
  L8s = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'L8s', 'backend': 'MSAZ'})
  L8s_v2 = PresetMachineConfig(cpu='8000m',memory='64Gi',metadata={'api_name': 'L8s v2', 'backend': 'MSAZ'})
  A7 = PresetMachineConfig(cpu='8000m',memory='56Gi',metadata={'api_name': 'A7', 'backend': 'MSAZ'})
  D13 = PresetMachineConfig(cpu='8000m',memory='56Gi',metadata={'api_name': 'D13', 'backend': 'MSAZ'})
  DS5_v2 = PresetMachineConfig(cpu='16000m',memory='56Gi',metadata={'api_name': 'DS5 v2', 'backend': 'MSAZ'})
  DS13_v2 = PresetMachineConfig(cpu='8000m',memory='56Gi',metadata={'api_name': 'DS13 v2', 'backend': 'MSAZ'})
  D5_v2 = PresetMachineConfig(cpu='16000m',memory='56Gi',metadata={'api_name': 'D5 v2', 'backend': 'MSAZ'})
  D13_v2 = PresetMachineConfig(cpu='8000m',memory='56Gi',metadata={'api_name': 'D13 v2', 'backend': 'MSAZ'})
  G2 = PresetMachineConfig(cpu='4000m',memory='56Gi',metadata={'api_name': 'G2', 'backend': 'MSAZ'})
  Gs2 = PresetMachineConfig(cpu='4000m',memory='56Gi',metadata={'api_name': 'Gs2', 'backend': 'MSAZ'})
  H8 = PresetMachineConfig(cpu='8000m',memory='56Gi',metadata={'api_name': 'H8', 'backend': 'MSAZ'})
  NC6 = PresetMachineConfig(cpu='6000m',memory='56Gi',gpu='1',gpu_name='nvidia-tesla-k80',metadata={'api_name': 'NC6', 'backend': 'MSAZ'})
  NV6 = PresetMachineConfig(cpu='6000m',memory='56Gi',gpu='1',gpu_name='nvidia-tesla-m60',metadata={'api_name': 'NV6', 'backend': 'MSAZ'})
  NV16as_v4 = PresetMachineConfig(cpu='16000m',memory='56Gi',gpu='0.5',gpu_name='amd-radeon-instinct-mi25',metadata={'api_name': 'NV16as v4', 'backend': 'MSAZ'})
  B12ms = PresetMachineConfig(cpu='12000m',memory='48Gi',metadata={'api_name': 'B12ms', 'backend': 'MSAZ'})
  A4m_v2 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'A4m v2', 'backend': 'MSAZ'})
  B8ms = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'B8ms', 'backend': 'MSAZ'})
  D8a_v4 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8a v4', 'backend': 'MSAZ'})
  D8as_v4 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8as v4', 'backend': 'MSAZ'})
  DC8_v2 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'DC8 v2', 'backend': 'MSAZ'})
  D8d_v4 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8d v4', 'backend': 'MSAZ'})
  D8ds_v4 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8ds v4', 'backend': 'MSAZ'})
  D8s_v3 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8s v3', 'backend': 'MSAZ'})
  D8s_v4 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8s v4', 'backend': 'MSAZ'})
  D8_v3 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8 v3', 'backend': 'MSAZ'})
  D8_v4 = PresetMachineConfig(cpu='8000m',memory='32Gi',metadata={'api_name': 'D8 v4', 'backend': 'MSAZ'})
  E4a_v4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4a v4', 'backend': 'MSAZ'})
  E4as_v4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4as v4', 'backend': 'MSAZ'})
  E4d_v4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4d v4', 'backend': 'MSAZ'})
  E4ds_v4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4ds v4', 'backend': 'MSAZ'})
  E4s_v3 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4s v3', 'backend': 'MSAZ'})
  E4s_v4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4s v4', 'backend': 'MSAZ'})
  E4_v3 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4 v3', 'backend': 'MSAZ'})
  E4_v4 = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'E4 v4', 'backend': 'MSAZ'})
  F16 = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'F16', 'backend': 'MSAZ'})
  F16s = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'F16s', 'backend': 'MSAZ'})
  F16s_v2 = PresetMachineConfig(cpu='16000m',memory='32Gi',metadata={'api_name': 'F16s v2', 'backend': 'MSAZ'})
  L4s = PresetMachineConfig(cpu='4000m',memory='32Gi',metadata={'api_name': 'L4s', 'backend': 'MSAZ'})
  A6 = PresetMachineConfig(cpu='4000m',memory='28Gi',metadata={'api_name': 'A6', 'backend': 'MSAZ'})
  D4 = PresetMachineConfig(cpu='8000m',memory='28Gi',metadata={'api_name': 'D4', 'backend': 'MSAZ'})
  D12 = PresetMachineConfig(cpu='4000m',memory='28Gi',metadata={'api_name': 'D12', 'backend': 'MSAZ'})
  DS4_v2 = PresetMachineConfig(cpu='8000m',memory='28Gi',metadata={'api_name': 'DS4 v2', 'backend': 'MSAZ'})
  DS12_v2 = PresetMachineConfig(cpu='4000m',memory='28Gi',metadata={'api_name': 'DS12 v2', 'backend': 'MSAZ'})
  D4_v2 = PresetMachineConfig(cpu='8000m',memory='28Gi',metadata={'api_name': 'D4 v2', 'backend': 'MSAZ'})
  D12_v2 = PresetMachineConfig(cpu='4000m',memory='28Gi',metadata={'api_name': 'D12 v2', 'backend': 'MSAZ'})
  G1 = PresetMachineConfig(cpu='2000m',memory='28Gi',metadata={'api_name': 'G1', 'backend': 'MSAZ'})
  Gs1 = PresetMachineConfig(cpu='2000m',memory='28Gi',metadata={'api_name': 'Gs1', 'backend': 'MSAZ'})
  NV8as_v4 = PresetMachineConfig(cpu='8000m',memory='28Gi',gpu='0.25',gpu_name='amd-radeon-instinct-mi25',metadata={'api_name': 'NV8as v4', 'backend': 'MSAZ'})
  A8_v2 = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'A8 v2', 'backend': 'MSAZ'})
  A2m_v2 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'A2m v2', 'backend': 'MSAZ'})
  B4ms = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'B4ms', 'backend': 'MSAZ'})
  D4a_v4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4a v4', 'backend': 'MSAZ'})
  D4as_v4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4as v4', 'backend': 'MSAZ'})
  DC4s_v2 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'DC4s v2', 'backend': 'MSAZ'})
  D4d_v4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4d v4', 'backend': 'MSAZ'})
  D4ds_v4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4ds v4', 'backend': 'MSAZ'})
  D4s_v3 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4s v3', 'backend': 'MSAZ'})
  D4s_v4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4s v4', 'backend': 'MSAZ'})
  D4_v3 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4 v3', 'backend': 'MSAZ'})
  D4_v4 = PresetMachineConfig(cpu='4000m',memory='16Gi',metadata={'api_name': 'D4 v4', 'backend': 'MSAZ'})
  E2a_v4 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2a v4', 'backend': 'MSAZ'})
  E2as_v4 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2as v4', 'backend': 'MSAZ'})
  E2d_v4 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2d v4', 'backend': 'MSAZ'})
  E2ds_v4 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2ds v4', 'backend': 'MSAZ'})
  E2s_v3 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2s v3', 'backend': 'MSAZ'})
  E2s_v4 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2s v4', 'backend': 'MSAZ'})
  E2_v3 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2 v3', 'backend': 'MSAZ'})
  E2_v4 = PresetMachineConfig(cpu='2000m',memory='16Gi',metadata={'api_name': 'E2 v4', 'backend': 'MSAZ'})
  F8 = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'F8', 'backend': 'MSAZ'})
  F8s = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'F8s', 'backend': 'MSAZ'})
  F8s_v2 = PresetMachineConfig(cpu='8000m',memory='16Gi',metadata={'api_name': 'F8s v2', 'backend': 'MSAZ'})
  A4 = PresetMachineConfig(cpu='8000m',memory='14Gi',metadata={'api_name': 'A4', 'backend': 'MSAZ'})
  A5 = PresetMachineConfig(cpu='2000m',memory='14Gi',metadata={'api_name': 'A5', 'backend': 'MSAZ'})
  D3 = PresetMachineConfig(cpu='4000m',memory='14Gi',metadata={'api_name': 'D3', 'backend': 'MSAZ'})
  D11 = PresetMachineConfig(cpu='2000m',memory='14Gi',metadata={'api_name': 'D11', 'backend': 'MSAZ'})
  DS3_v2 = PresetMachineConfig(cpu='4000m',memory='14Gi',metadata={'api_name': 'DS3 v2', 'backend': 'MSAZ'})
  DS11_v2 = PresetMachineConfig(cpu='2000m',memory='14Gi',metadata={'api_name': 'DS11 v2', 'backend': 'MSAZ'})
  D3_v2 = PresetMachineConfig(cpu='4000m',memory='14Gi',metadata={'api_name': 'D3 v2', 'backend': 'MSAZ'})
  D11_v2 = PresetMachineConfig(cpu='2000m',memory='14Gi',metadata={'api_name': 'D11 v2', 'backend': 'MSAZ'})
  NV4as_v4 = PresetMachineConfig(cpu='4000m',memory='14Gi',gpu='0.125',gpu_name='amd-radeon-instinct-mi25',metadata={'api_name': 'NV4as v4', 'backend': 'MSAZ'})
  A4_v2 = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'A4 v2', 'backend': 'MSAZ'})
  B2ms = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'B2ms', 'backend': 'MSAZ'})
  D2a_v4 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2a v4', 'backend': 'MSAZ'})
  D2as_v4 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2as v4', 'backend': 'MSAZ'})
  DC2s_v2 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'DC2s v2', 'backend': 'MSAZ'})
  D2d_v4 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2d v4', 'backend': 'MSAZ'})
  D2ds_v4 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2ds v4', 'backend': 'MSAZ'})
  D2s_v3 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2s v3', 'backend': 'MSAZ'})
  D2s_v4 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2s v4', 'backend': 'MSAZ'})
  D2_v3 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2 v3', 'backend': 'MSAZ'})
  D2_v4 = PresetMachineConfig(cpu='2000m',memory='8Gi',metadata={'api_name': 'D2 v4', 'backend': 'MSAZ'})
  F4 = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'F4', 'backend': 'MSAZ'})
  F4s = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'F4s', 'backend': 'MSAZ'})
  F4s_v2 = PresetMachineConfig(cpu='4000m',memory='8Gi',metadata={'api_name': 'F4s v2', 'backend': 'MSAZ'})
  A3 = PresetMachineConfig(cpu='4000m',memory='7Gi',metadata={'api_name': 'A3', 'backend': 'MSAZ'})
  D2 = PresetMachineConfig(cpu='2000m',memory='7Gi',metadata={'api_name': 'D2', 'backend': 'MSAZ'})
  DS2_v2 = PresetMachineConfig(cpu='2000m',memory='7Gi',metadata={'api_name': 'DS2 v2', 'backend': 'MSAZ'})
  D2_v2 = PresetMachineConfig(cpu='2000m',memory='7Gi',metadata={'api_name': 'D2 v2', 'backend': 'MSAZ'})
  A2_v2 = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'A2 v2', 'backend': 'MSAZ'})
  B2s = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'B2s', 'backend': 'MSAZ'})
  DC1s_v2 = PresetMachineConfig(cpu='1000m',memory='4Gi',metadata={'api_name': 'DC1s v2', 'backend': 'MSAZ'})
  F2 = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'F2', 'backend': 'MSAZ'})
  F2s = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'F2s', 'backend': 'MSAZ'})
  F2s_v2 = PresetMachineConfig(cpu='2000m',memory='4Gi',metadata={'api_name': 'F2s v2', 'backend': 'MSAZ'})
  A2 = PresetMachineConfig(cpu='2000m',memory='3.5Gi',metadata={'api_name': 'A2', 'backend': 'MSAZ'})
  D1 = PresetMachineConfig(cpu='1000m',memory='3.5Gi',metadata={'api_name': 'D1', 'backend': 'MSAZ'})
  DS1_v2 = PresetMachineConfig(cpu='1000m',memory='3.5Gi',metadata={'api_name': 'DS1 v2', 'backend': 'MSAZ'})
  D1_v2 = PresetMachineConfig(cpu='1000m',memory='3.5Gi',metadata={'api_name': 'D1 v2', 'backend': 'MSAZ'})
  A1_v2 = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'A1 v2', 'backend': 'MSAZ'})
  B1ms = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'B1ms', 'backend': 'MSAZ'})
  F1 = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'F1', 'backend': 'MSAZ'})
  F1s = PresetMachineConfig(cpu='1000m',memory='2Gi',metadata={'api_name': 'F1s', 'backend': 'MSAZ'})
  A1 = PresetMachineConfig(cpu='1000m',memory='1.75Gi',metadata={'api_name': 'A1', 'backend': 'MSAZ'})
  B1s = PresetMachineConfig(cpu='1000m',memory='1Gi',metadata={'api_name': 'B1s', 'backend': 'MSAZ'})
  B1ls = PresetMachineConfig(cpu='1000m',memory='0.5Gi',metadata={'api_name': 'B1ls', 'backend': 'MSAZ'})
